Module: Amp

Defined in:
lib/amp-core/templates/template.rb,
lib/amp-core.rb,
lib/amp-core/amp_plugin.rb,
lib/amp-core/support/hex_string.rb,
lib/amp-core/templates/template.rb,
lib/amp-core/repository/repository.rb,
lib/amp-core/support/rooted_opener.rb,
lib/amp-core/support/encoding_utils.rb,
lib/amp-core/support/platform_utils.rb,
lib/amp-core/command_ext/repository_loading.rb,
lib/amp-core/repository/generic_repo_picker.rb,
lib/amp-core/repository/abstract/abstract_changeset.rb,
lib/amp-core/repository/abstract/abstract_local_repo.rb,
lib/amp-core/repository/abstract/abstract_staging_area.rb,
lib/amp-core/repository/abstract/abstract_versioned_file.rb,
lib/amp-core/repository/abstract/common_methods/changeset.rb,
lib/amp-core/repository/abstract/common_methods/local_repo.rb,
lib/amp-core/repository/abstract/common_methods/staging_area.rb,
lib/amp-core/repository/abstract/common_methods/versioned_file.rb

Overview

Licensing Information # # The following code is licensed, as standalone code, under # the Ruby License, unless otherwise directed within the code. # # For information on the license of this code when distributed # with and used in conjunction with the other modules in the # Amp project, please see the root-level LICENSE file. # # © Michael J. Edgar and Ari Brown, 2009-2010 # #

Defined Under Namespace

Modules: Command, Core, KernelMethods, Support